@@ -2,28 +2,34 @@
 
 import logging
 import logging.handlers
-import string
 from django.core import mail
 from django.conf import settings
 from django.contrib import messages
+from . import strip_accents
+
+levelname_to_int = {
+    'DEBUG': messages.DEBUG,
+    'INFO': messages.INFO,
+    'WARNING': messages.WARNING,
+    'ERROR': messages.ERROR,
+}
 
 
-# Python < 2.7.
-class NullHandler(logging.Handler):
-    def emit(self, record):
-        pass
+# Kept for backward compatibility.
+class NullHandler(logging.NullHandler):
+    pass
 
 
 # http://www.red-dove.com/python_logging.html
 class BufferingSMTPHandler(logging.handlers.BufferingHandler):
-    def __init__(self, mailhost, fromaddr, toaddrs, subject, capacity):
+    def __init__(self, mailhost, fromaddr, toaddrs, subject, capacity, fmt="%(asctime)s %(levelname)-5s %(message)s"):
         logging.handlers.BufferingHandler.__init__(self, capacity)
         self.mailhost = mailhost
         self.mailport = None
         self.fromaddr = fromaddr
         self.toaddrs = toaddrs
         self.subject = subject
-        self.setFormatter(logging.Formatter("%(asctime)s %(levelname)-5s %(message)s"))
+        self.setFormatter(logging.Formatter(fmt))
 
     def flush(self):
         if len(self.buffer) > 0:
@@ -33,15 +39,19 @@ class BufferingSMTPHandler(logging.handlers.BufferingHandler):
                 if not port:
                     port = smtplib.SMTP_PORT
                 smtp = smtplib.SMTP(self.mailhost, port)
-                msg = "From: %s\r\nTo: %s\r\nSubject: %s\r\n\r\n" % (self.fromaddr, string.join(self.toaddrs, ","), self.subject)
+                msg = u"From: {}\r\nTo: {}\r\nSubject: {}\r\n\r\n".format(
+                    self.fromaddr,
+                    ",".join(self.toaddrs),
+                    self.subject
+                ).encode('utf8')
                 for record in self.buffer:
-                    s = self.format(record)
-                    print s
-                    msg = msg + s + "\r\n"
+                    msg_bit = self.format(record)
+                    msg = msg + strip_accents(msg_bit).encode('ascii') + b"\r\n"
                 smtp.sendmail(self.fromaddr, self.toaddrs, msg)
                 smtp.quit()
             except:
-                self.handleError(None)  # no particular record
+                for record in self.buffer:
+                    self.handleError(record)
             self.buffer = []
 
 
@@ -55,7 +65,8 @@ class BaseEmailHandler(logging.Handler):
     def emit(self, record):
         subject = u'%s[%s] : %s' % (settings.EMAIL_SUBJECT_PREFIX, record.levelname, self.subject)
         message = record.msg
-        mail.send_mail(subject, message, settings.DEFAULT_FROM_EMAIL, self.recipient_list, fail_silently=True)
+        mail.send_mail(subject, message, settings.DEFAULT_FROM_EMAIL, self.recipient_list,
+                       fail_silently=True)
 
 
 class AdminEmailHandler(BaseEmailHandler):
@@ -64,12 +75,22 @@ class AdminEmailHandler(BaseEmailHandler):
         BaseEmailHandler.emit(self, record)
 
 
-levelname_to_int = {
-    'DEBUG': messages.DEBUG,
-    'INFO': messages.INFO,
-    'WARNING': messages.WARNING,
-    'ERROR': messages.ERROR,
-}
+class BufferingAdminEmailHandler(BufferingSMTPHandler):
+    def __init__(self, subject="", capacity=1000):
+        BufferingSMTPHandler.__init__(self, settings.EMAIL_HOST, settings.SERVER_EMAIL,
+                                      [email for name, email in settings.ADMINS],
+                                      subject, capacity)
+
+    def flush(self):
+        if len(self.buffer) > 0:
+            msg = "From: %s\r\nTo: %s\r\nSubject: %s\r\n\r\n" % (
+                self.fromaddr,
+                ",".join(self.toaddrs),
+                self.subject)
+            body = "\r\n".join([self.format(r) for r in self.buffer])
+            email = mail.EmailMessage(self.subject, msg + body, self.fromaddr, self.toaddrs)
+            email.send()
+            self.buffer = []
 
 
 class MessagelHandler(logging.Handler):
